Changelog
=========
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

[Unreleased]
------------

Added
~~~~~
- Additional examples to the documentation

Changed
~~~~~~~
- Fixed some of the method implementation to reduce the number of methods that modify the underlying collections.
- Changed the the name of the changelog file and defined it's format and contents


[0.1.0] - 2017-08-27
--------------------
Initial release. Includes the first API implementation, tests and documentation.

.. Added
   ~~~~~
   Changed
   ~~~~~~~
   Fixed
   ~~~~~
   Removed
   ~~~~~~~
